# UNDP Albania Solar Calculator
A solar calculator and information app for Albanian businesses

## Contents
1. [Tips](#tips)
2. [Number of Panels Calculator](#number-of-panels-calculator)
3. [Payback Period Calculator](#payback-period-calculator)
4. [Business Solar Resource Page](#business-solar-resource-page)
5. [Rules for Coding Style](#rules-for-coding-style)

 ## Tips
 - If you are unsure of what a certain field is asking for, click on ? beside the field box to get a brief explanation.
 - On the top left corner of **Resources**, click on the hamburger button next to **Contents** to easily find a section on the page. Click on a section and it will scroll to the section for you.
 - If you are having trouble reading an image or infographic in **Resources**, click on the image and the image will enlarge.

 ## Number of Panels Calculator

This calculator determines the number of panels you would need to install to cover your entire electricity needs.
 1) Select the municipality that your building is located in under **Select your municipality**. The municipality you select is used to determine the average amount of sunlight per month/year for your building.
 2) Scroll through the table under **Solar Panel Info** and click on **Use this panel** under **Panel Selection** if you find a solar panel model you are interested in using.
 
    OR
    
    - Click **Enter photovoltaics manually** and enter the following fields manually:
    - **Cost for one kW of panel**: In Euros, the price of a singular solar panel that you are looking to purchase.
    - **Area of one solar panel**: In meters-squared, the length times the width of a singular solar panel that you are looking to purchase.
    - **Peak capacity of one solar panel (W)**: In kilowatts (kW), the capacity of a singular solar panel that you are looking to purchase.
    
    OR
    
    - Click **Switch to using efficiency** and enter the efficiency (%) of a singular solar panel that you are looking to purchase under **Efficiency of solar panels** if you do not know the peak capacity.
 3) Under **Electricity usage per month**, enter, in kilowatt-hours (kWh), the amount of electricity your business uses on average per month. This information should be on your electricity bill, or can be easily calculated by taking the average of the last 12 months of electricity usage for your business. If instead you would like to enter your yearly electricity bill, click on the slider to swap between **months** and **years**.
 4) On the right hand panel, the number of panels you need for your system is under **Panels Required**.

 ## Payback Period Calculator

This calculator determines how long it will take to break even on your initial solar panel system purchase.
 1) If you haven’t already from the previous calculator, select the municipality that your building is located in under **Select your municipality**. The municipality you select is used to determine the average amount of sunlight per month/year for your building.
 2) Scroll through the table under **Example Solar Photovoltaics** and click on Use this panel under **Panel Selection** if you find a solar panel model you are interested in using.
 
    OR
    
    Click **Enter photovoltaics manually** and enter the following fields manually:
    - **Cost for one kW of panel**: In Euros, the price of a singular solar panel that you are looking to purchase.
    - **Area of one solar panel**: In meters-squared, the length times the width of a singular solar panel that you are looking to purchase.
    - **Peak capacity of one solar panel (W)**: In kilowatts (kW), the capacity of a singular solar panel that you are looking to purchase.
    
    OR
    
    - Click **Switch to using efficiency** and enter the efficiency (%) of a singular solar panel that you are looking to purchase under **Efficiency of solar panels** if you do not know the peak capacity.
 3) Under **Price of electricity** enter, in Lek/kWh, the most recent price of electricity per kilowatt hour for your business.
 4) Under **Flat roof space available for solar** enter, in meters-squared, the amount of flat, open space you have on your business' roof for solar photovoltaics. If you don't know the exact amount, provide a rough estimate. Keep in mind that the roof space must receive sunlight for solar photovoltaics to work there.
 5) Under **Percent of PV Share**, enter how much of your total energy usage you want to replace with solar photovoltaic generation. For example, if you enter “50”, then 50% of your current electricity usage will be generated by solar photovoltaics, and the other 50% will come from the grid.
 6) On the right hand panel, the energy system generated by the system, the total amount saved, the total cost, the payback period, and CO2 savings is shown.

 ## Business Solar Resource Page 

Below are explanations of the sections found on the application’s resource page.

 ### Impacts of Solar Energy
This section provides an explanation on:
 - How solar energy is beneficial to the environment 
 - Solar and climate
 - Albania has high solar irradiation. That means that using solar energy in Albania is a good idea. 

 ### The benefits of solar energy for your business
This section provides:
 - Advantages of a business using solar energy for their electricity needs. 

 ### Should your business go solar?
This section provides:
 - A list of important questions businesses may have when considering solar energy.

 ### Contact for more information
This section explains:
 - Who a business can contact to learn more about solar energy, solar systems, and financing options. 

 ### Applying for a Building Permit
This section explains:
- How a business can apply for a building permit to start their solar installation process. 

 ### The Day of Installment
This section explains:
 - What happens on installation day when solar installers arrive and start setting up the solar system. 

 ### Financing Your System
This section provides:
 - Different options for a business to finance their solar system through 
   - a cash purchase
   - taking out a loan
   - applying for a grant

 ### Business Solar Success Story
This section provides:
 - Success stories of businesses that have implemented a solar system for their electricity needs. 

 ### Solar Myths and Misconceptions
This section addresses:
 - Common misconceptions businesses may have about using solar energy.

 ### Choosing the right solar installer
This section explains:
 - What qualities makes a suitable solar installer to install their system.

 ### Different Types of Panels
This section explains:
 - The difference between monocrystalline panels and polycrystalline panels.

 ### Fire Safety
This section provides:
 - Guidance for businesses on how to protect solar panels from equipment fires.
 
 ## Rules for Coding Style
1) Comment your code
2) Branches
- Make new branches for new features, bug fixes, and other code edits
- Delete branches when they've been merged successfully
- Make branches from issues to resolve them
3) Other Rules
- Branches, and HTML element class names and ids should be in <i>kebab-case</i> (Have words seperated by a hyphen)
- js files that represent a page in the app should be <i>PascalCase</i> (Each word starts with a capital letter, no spaces). All other files should be <i>snake_case</i> (Spaces are represented by the "_" character)
- Use tabs to indent lines
- Indent all children of an HTML element
- Use css for all styling
